summaryrefslogtreecommitdiff
path: root/src/vm/eventtrace.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/vm/eventtrace.cpp')
-rw-r--r--src/vm/eventtrace.cpp22
1 files changed, 17 insertions, 5 deletions
diff --git a/src/vm/eventtrace.cpp b/src/vm/eventtrace.cpp
index 1eb89385a6..84ce711c1f 100644
--- a/src/vm/eventtrace.cpp
+++ b/src/vm/eventtrace.cpp
@@ -197,7 +197,10 @@ BOOL IsRundownNgenKeywordEnabledAndNotSuppressed()
{
LIMITED_METHOD_CONTRACT;
- return
+ return
+#ifdef FEATURE_PERFTRACING
+ EventPipeHelper::Enabled() ||
+#endif // FEATURE_PERFTRACING
(
ETW_TRACING_CATEGORY_ENABLED(
MICROSOFT_WINDOWS_DOTNETRUNTIME_RUNDOWN_PROVIDER_Context,
@@ -4465,10 +4468,10 @@ extern "C"
#ifdef _TARGET_AMD64_
// We only do this on amd64 (NOT ARM, because ARM uses frame based stack crawling)
// If we have turned on the JIT keyword to the VERBOSE setting (needed to get JIT names) then
// we assume that we also want good stack traces so we need to publish unwind information so
// ETW can get at it
- if(bIsPublicTraceHandle && ETW_CATEGORY_ENABLED((*context), TRACE_LEVEL_VERBOSE, CLR_RUNDOWNJIT_KEYWORD))
+ if(bIsPublicTraceHandle && ETW_CATEGORY_ENABLED((*context), TRACE_LEVEL_INFORMATION, CLR_RUNDOWNJIT_KEYWORD))
UnwindInfoTable::PublishUnwindInfo(g_fEEStarted != FALSE);
#endif
@@ -6760,9 +6763,9 @@ VOID ETW::MethodLog::SendHelperEvent(ULONGLONG ullHelperStartAddress, ULONG ulHe
ulHelperSize,
0,
methodFlags,
- NULL,
+ NULL,
pHelperName,
- NULL,
+ NULL,
GetClrInstanceId());
}
}
@@ -7385,3 +7388,12 @@ VOID ETW::EnumerationLog::EnumerationHelper(Module *moduleFilter, BaseDomain *do
}
#endif // !FEATURE_REDHAWK
+
+#ifdef FEATURE_PERFTRACING
+#include "eventpipe.h"
+bool EventPipeHelper::Enabled()
+{
+ LIMITED_METHOD_CONTRACT;
+ return EventPipe::Enabled();
+}
+#endif // FEATURE_PERFTRACING
@@ -4465,10 +4468,10 @@ extern "C"
#ifdef _TARGET_AMD64_
// We only do this on amd64 (NOT ARM, because ARM uses frame based stack crawling)
- // If we have turned on the JIT keyword to the VERBOSE setting (needed to get JIT names) then
+ // If we have turned on the JIT keyword to the INFORMATION setting (needed to get JIT names) then
// we assume that we also want good stack traces so we need to publish unwind information so
// ETW can get at it